package pusher

import (
	"bytes"
	"errors"
	"fmt"
	"io/ioutil"
	"net/http"
	"strconv"
	"time"
)

// change timeout to time.Duration
func request(method, url string, body []byte, timeout time.Duration) ([]byte, error) {

	if timeout == 0 {
		timeout = time.Second * 5
	}

	client := &http.Client{Timeout: timeout}

	// use httpClient Timeout attribute - otherwise there will be a leak

	req, err := http.NewRequest(method, url, bytes.NewBuffer(body))
	req.Header.Set("Content-Type", "application/json")
	resp, err := client.Do(req)
	if err != nil {
		return nil, err
	}
	defer resp.Body.Close()

	return processResponse(resp)
}

func processResponse(response *http.Response) ([]byte, error) {
	responseBody, err := ioutil.ReadAll(response.Body)

	if err != nil {
		return nil, err
	}

	if response.StatusCode == 200 {
		return responseBody, nil
	} else {
		message := fmt.Sprintf("Status Code: %s - %s", strconv.Itoa(response.StatusCode), string(responseBody))
		err := errors.New(message)
		return nil, err
	}
}
